@@ -528,76 +528,6 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         predictions.name = self.input_target_name
         return infer_feature_types(predictions)
 
-    def _mlflow_load_model(self):
-        """Loads model from mlflow.
-
-        Returns:
-            mlflow.pyfunc loaded model
-        """
-        return mlflow.pyfunc.load_model(
-            model_uri=f"models:/{self.model_name}/{self.model_version}"
-        )   
-
-    def _parallel_predict(self, X):
-        """Make predictions using selected features.
-
-        Arguments:
-            X (dd.DataFrame, pd.DataFrame, or np.ndarray): Data of shape [n_samples, n_features]
-
-        Returns:
-            np.array: Predicted values.
-        """
-
-        print('loading model from mlflow...')
-        try:
-            model = self._mlflow_load_model() 
-        except:
-            try:
-                time.sleep(60)
-                model = self._mlflow_load_model()
-            except:
-                time.sleep(60)
-                model = self._mlflow_load_model()
-
-        class avm_wrapper(mlflow.pyfunc.PythonModel):
-            def __init__(self, model):
-                self.model = model
-
-            def predict(self, X):
-                return self.model.predict(X).values
-            
-        dask_component_graph = ParallelPostFit(avm_wrapper(model))
-        return dask_component_graph.predict(X) 
-
-
-    def parallel_predict(self, X, npartitions=64, model_name='avm', model_version='Production', context={'conf_min':0.5, 'batch_sample_sets':1, 'min_sample_sz':5, 'max_sample_sz':15, 'pred_interval':0.68}, cols=['unit_id','avm','avm_lower','avm_upper','conf','ts','latest_production_version','latest_staging_version']):
-        """Make predictions using selected features.
-
-        Arguments:
-            X (dd.DataFrame, pd.DataFrame, or np.ndarray): Data of shape [n_samples, n_features]
-
-        Returns:
-            pd.DataFrame: Predicted values.
-        """
-
-        self.model_name=model_name
-        self.model_version=model_version
-        self.context = context
-
-        if not isinstance(X, dd._Frame):
-            print('Building a dask dataframe...')
-            X = dd.from_pandas(X, npartitions=npartitions)
-
-        X = dask.persist(X)
-        _ = wait(X)
-        X = X[0]
-
-        preds = X.map_partitions(
-                self._parallel_predict, meta=np.array([1])
-        )
-
-        # preds should return an array (in map_partitions is specified meta=np.array([1]))
-        return pd.DataFrame(preds.compute(), columns=cols)
         
 
     @abstractmethod
