@@ -264,8 +264,8 @@ def preprocess_data(data, drop_outlier=True, target='Price_p', test_size=0.15, s
     y_test = y.iloc[test]
     X_train = X_train.drop(target, axis=1)
     X_test = X_test.drop(target, axis=1)
-
     return X_train, X_test, y_train, y_test
+    
 
 def merge_train_w_lookup_table(train, lookup_table):
     if 'PROPERTY_TYPE_e__' in lookup_table.columns:
@@ -292,4 +292,101 @@ def merge_train_w_lookup_table(train, lookup_table):
     new_X_train['POSTCODE_AREA'] = train['POSTCODE_AREA']
     new_X_train['density_count'] = train['density_count']
     new_X_train[target] = train[target]
-    return new_X_train
\ No newline at end of file
+    return new_X_train
+
+
+def get_bounds(resp, y_predd):
+    try:
+        resp[ 'avm_lower' ] = round(
+                resp[ 'avm' ].astype(float) + resp[ 'avm' ].astype(float) * resp[ 'avm_lower' ].astype(float),
+                0)
+    except:
+        pass
+
+    try:
+        resp[ 'avm_upper' ] = round(
+                resp[ 'avm' ].astype(float) + resp[ 'avm' ].astype(float) * resp[ 'avm_upper' ].astype(float),
+                0)
+    except:
+        pass
+
+    if (y_predd.values[0] - resp[ 'avm_lower' ].values[0] ) > (resp[ 'avm_upper' ].values[0] - y_predd.values[0]):
+        fsd = y_predd.values[0] - resp[ 'avm_lower' ].values[0]
+    else:
+        fsd = resp[ 'avm_upper' ].values[0] - y_predd.values[0]
+
+    conf = 1.0 - fsd / y_predd.values[0]
+    resp['conf'] = [conf]
+
+    return resp
+  
+  
+def correct(predictions, conf_min=0.5):
+    predictions[ 'avm' ] = round(predictions[ 'avm' ].astype(float), 0)
+    predictions[ 'conf' ] = round(predictions[ 'conf' ].astype(float), 2)
+    try :
+      predictions[ 'avm' ] = np.where(predictions[ 'avm' ].astype(float) < 0.0, np.nan, predictions[ 'avm' ].astype(float))
+    except :
+      pass
+    try :
+      predictions[ 'avm_lower' ] = np.where(predictions[ 'avm_lower' ].astype(float) < 0.0, np.nan, predictions[ 'avm_lower' ].astype(float))
+    except :
+      pass
+    try :
+      predictions[ 'avm_upper' ] = np.where(predictions[ 'avm_upper' ].astype(float) < 0.0, np.nan, predictions[ 'avm_upper' ].astype(float))
+    except :
+      pass
+    try :
+      predictions[ 'avm_lower' ] = np.where(predictions[ 'avm_lower' ].astype(float) > predictions[ 'avm' ].astype(float), np.nan,
+                                   predictions[ 'avm_lower' ].astype(float))
+    except :
+      pass
+    try :
+      predictions[ 'avm_upper' ] = np.where(predictions[ 'avm_upper' ].astype(float) < predictions[ 'avm' ].astype(float), np.nan,
+                                   predictions[ 'avm_upper' ].astype(float))
+    except :
+      pass
+    try :
+      predictions.name = self.input_target_name
+    except :
+      pass
+
+    try :
+      predictions[ 'conf' ] = np.where(predictions[ 'conf' ].astype(float) < conf_min, '< 0.5',
+                                   predictions[ 'conf' ].astype(float))
+    except :
+      pass
+    
+    
+    return predictions
+  
+  
+def combine_confs(preds, confs):
+    ll = []
+    ct = 0
+    for unit in preds['unit_indx'].values:
+      try:
+        resp = pd.DataFrame({})
+        
+        p = preds[preds['unit_indx']==unit]
+        _key = p['key'].values[0]
+        
+        c = confs[confs['key']==_key]
+        
+        lower = 1.0 -  c['avm'] / c['avm_lower'] 
+        upper = 1.0 -  c['avm'] / c['avm_upper']
+        
+        resp['unit_indx'] = p['unit_indx']
+        resp['avm'] = p['avm']
+        resp['avm_lower'] = [lower]
+        resp['avm_upper'] = [upper]
+        
+        for _unit_id in resp['unit_indx'].unique():
+          unit = resp[resp['unit_indx']==_unit_id]
+          r = _get_bounds(unit, unit['avm'])
+          ll.append(r)
+          ct+=1
+      except: pass
+      
+    return correct(pd.concat(ll))
+      
